@@ -28,6 +28,7 @@
 #include <gtk/gtkvbbox.h>
 #include <libgnomedb/gnome-db-grid.h>
 #include <libgnomedb/gnome-db-i18n.h>
+#include <libgnomedb/gnome-db-stock.h>
 #include <libgnomedb/gnome-db-util.h>
 #include "provider-config.h"
 
@@ -86,6 +87,7 @@ provider_config_new (void)
 	GtkWidget *box;
 	GtkWidget *button;
 	GtkWidget *label;
+	gchar *title;
 
 	priv = g_new0 (ProviderConfigPrivate, 1);
 	provider = gnome_db_new_vbox_widget (FALSE, 6);
@@ -98,8 +100,15 @@ provider_config_new (void)
 
 	/* create the provider list */
 	priv->provider_list = gnome_db_grid_new ();
-	gnome_db_grid_set_title (GNOME_DB_GRID (priv->provider_list), _("Providers"));
+
+	title = g_strdup_printf ("<b>%s</b>\n%s", _("Providers"),
+				 _("Installed providers"));
+	gnome_db_grid_set_title (GNOME_DB_GRID (priv->provider_list), title);
+	g_free (title);
+
 	gnome_db_grid_set_show_title (GNOME_DB_GRID (priv->provider_list), TRUE);
+	gnome_db_grid_set_show_title_icon (GNOME_DB_GRID (priv->provider_list), TRUE);
+	gnome_db_grid_set_title_icon_from_stock (GNOME_DB_GRID (priv->provider_list), GNOME_DB_STOCK_DATABASE, GTK_ICON_SIZE_BUTTON);
 	gtk_widget_show (priv->provider_list);
 	gtk_table_attach (GTK_TABLE (table), priv->provider_list, 0, 1, 0, 1,
 			  GTK_FILL | GTK_SHRINK | GTK_EXPAND,
