@@ -404,7 +404,7 @@ selection_foreach (GtkTreeModel *tree_model,
 	g_return_if_fail (iter != NULL);
 
 	gtk_tree_model_get (tree_model, iter, 0, &iter_info, -1);
-	if (iter_info && iter_info->row == 0) {
+	if (iter_info) {
 		g_signal_emit (G_OBJECT (grid), gnome_db_grid_signals[ROW_SELECTED],
 			       0, iter_info->row);
 	}
